@@ -111,7 +111,7 @@ bool AdBlockManager::block(QWebEngineUrlRequestInfo &request, QString &ruleFilte
     QElapsedTimer timer;
     timer.start();
 #endif
-    const QString urlString = request.requestUrl().toEncoded().toLower();
+    const QString urlString = QString::fromUtf8(request.requestUrl().toEncoded().toLower());
     const QString urlDomain = request.requestUrl().host().toLower();
     const QString urlScheme = request.requestUrl().scheme().toLower();
 
@@ -242,7 +242,7 @@ bool AdBlockManager::removeSubscription(AdBlockSubscription* subscription)
 
 AdBlockCustomList* AdBlockManager::customList() const
 {
-    for (AdBlockSubscription* subscription : qAsConst(m_subscriptions)) {
+    for (AdBlockSubscription* subscription : std::as_const(m_subscriptions)) {
         auto* list = qobject_cast<AdBlockCustomList*>(subscription);
 
         if (list) {
@@ -296,11 +296,7 @@ void AdBlockManager::load()
         }
 
         QTextStream textStream(&file);
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-        textStream.setCodec("UTF-8");
-#else
         textStream.setEncoding(QStringConverter::Utf8);
-#endif
         QString title = textStream.readLine(1024).remove(QLatin1String("Title: "));
         QUrl url = QUrl(textStream.readLine(1024).remove(QLatin1String("Url: ")));
 
@@ -334,7 +330,7 @@ void AdBlockManager::load()
     m_subscriptions.append(customList);
 
     // Load all subscriptions
-    for (AdBlockSubscription* subscription : qAsConst(m_subscriptions)) {
+    for (AdBlockSubscription* subscription : std::as_const(m_subscriptions)) {
         subscription->loadSubscription(m_disabledRules);
 
         connect(subscription, &AdBlockSubscription::subscriptionUpdated, mApp, &MainApplication::reloadUserStyleSheet);
@@ -371,7 +367,7 @@ void AdBlockManager::updateMatcher()
 
 void AdBlockManager::updateAllSubscriptions()
 {
-    for (AdBlockSubscription* subscription : qAsConst(m_subscriptions)) {
+    for (AdBlockSubscription* subscription : std::as_const(m_subscriptions)) {
         subscription->updateSubscription();
     }
 
@@ -387,7 +383,7 @@ void AdBlockManager::save()
         return;
     }
 
-    for (AdBlockSubscription* subscription : qAsConst(m_subscriptions)) {
+    for (AdBlockSubscription* subscription : std::as_const(m_subscriptions)) {
         subscription->saveSubscription();
     }
 
@@ -432,7 +428,7 @@ QString AdBlockManager::elementHidingRulesForDomain(const QUrl &url) const
 
 AdBlockSubscription* AdBlockManager::subscriptionByName(const QString &name) const
 {
-    for (AdBlockSubscription* subscription : qAsConst(m_subscriptions)) {
+    for (AdBlockSubscription* subscription : std::as_const(m_subscriptions)) {
         if (subscription->title() == name) {
             return subscription;
         }
