@@ -53,16 +53,12 @@
 #include <QWebEnginePage>
 #include <QWebEngineUrlRequestInfo>
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+/* TODO Qt6 Replace with PUBLIC API */
 #include <QtCore/private/qurl_p.h>
 #include <QtNetwork/private/qtldurl_p.h>
-#endif
 
 static QString getTopLevelDomain(const QUrl &url)
 {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    return url.topLevelDomain();
-#else
     // QUrl::topLevelDomain() was removed in Qt6.
     // The following is copied from the old "qTopLevelDomain" code in Qt6::Network.
     // It was removed in this commit: https://github.com/qt/qtbase/commit/50b30976837be0969efdccced68cfb584d99981a
@@ -80,8 +76,7 @@ static QString getTopLevelDomain(const QUrl &url)
 
     //return qt_ACE_do(tld, ToAceOnly, AllowLeadingDot, {});
     // TODO QT6 - QUrl::toAce() uses ForbidLeadingDot, while the old QUrl::topLevelDomain() used AllowLeadingDot. Does this matter?
-    return QString(QUrl::toAce(tld));
-#endif
+    return QString(QString::fromUtf8(QUrl::toAce(tld)));
 }
 
 static QString toSecondLevelDomain(const QUrl &url)
@@ -240,7 +235,7 @@ bool AdBlockRule::urlMatch(const QUrl &url) const
         return false;
     }
 
-    const QString encodedUrl = url.toEncoded();
+    const QString encodedUrl = QString::fromUtf8(url.toEncoded());
     const QString domain = url.host();
 
     return stringMatch(domain, encodedUrl);
@@ -284,14 +279,14 @@ bool AdBlockRule::matchDomain(const QString &domain) const
     }
 
     if (m_blockedDomains.isEmpty()) {
-        for (const QString &d : qAsConst(m_allowedDomains)) {
+        for (const QString &d : std::as_const(m_allowedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return true;
             }
         }
     }
     else if (m_allowedDomains.isEmpty()) {
-        for (const QString &d : qAsConst(m_blockedDomains)) {
+        for (const QString &d : std::as_const(m_blockedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return false;
             }
@@ -299,13 +294,13 @@ bool AdBlockRule::matchDomain(const QString &domain) const
         return true;
     }
     else {
-        for (const QString &d : qAsConst(m_blockedDomains)) {
+        for (const QString &d : std::as_const(m_blockedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return false;
             }
         }
 
-        for (const QString &d : qAsConst(m_allowedDomains)) {
+        for (const QString &d : std::as_const(m_allowedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return true;
             }
